========================================
 django_ical.feedgenerator
========================================

.. contents::
    :local:
.. currentmodule:: django_ical.feedgenerator

.. automodule:: django_ical.feedgenerator
    :members:
